html, body {
  margin: 0;
  padding: 0;
  width: 100%;
  height: 100%;
  line-height: 0;
  font-size: 0;
}
text {
  font-weight: 300;
  font-family: "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 14px;
}
.node rect {
  stroke: #999;
  fill: #fff;
  stroke-width: 1.5px;
}
.edgePath path {
  stroke: #333;
  stroke-width: 1.5px;
}